==> applet-sa-boot-starter-3.1.4-sources.jar: cn/sinozg/applet/sa/handler/SaGlobalExceptionHandler.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.sa.handler;

import cn.dev33.satoken.exception.NotLoginException;
import cn.dev33.satoken.exception.NotPermissionException;
import cn.dev33.satoken.exception.NotRoleException;
import cn.dev33.satoken.exception.SaTokenException;
import cn.sinozg.applet.common.constant.BaseConstants;
import cn.sinozg.applet.common.utils.MsgUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

/**
 * sa 异常全局拦截器
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-01-05 17:34
 */
@RestControllerAdvice
@Order(Ordered.HIGHEST_PRECEDENCE)
public class SaGlobalExceptionHandler {

    private static final Logger log = LoggerFactory.getLogger(SaGlobalExceptionHandler.class);
    /**
     * 鉴权异常处理
     * @param request HttpServletRequest
     * @param e 异常
     */
    @ResponseBody
    @ExceptionHandler(NotLoginException.class)
    public void nonLoginException(HttpServletRequest request, HttpServletResponse response, NotLoginException e) {
        log.error("未授权！！");
        String errorMsg = e.getMessage();
        if (StringUtils.isNotEmpty(errorMsg)) {
            errorMsg = StringUtils.substringBefore(errorMsg, "：");
        }
        MsgUtil.httpError(response, request, e, HttpStatus.UNAUTHORIZED, BaseConstants.DEFAULT_CODE, errorMsg);
    }

    /**
     * 权限相关异常处理
     * @param request HttpServletRequest
     * @param response HttpServletResponse
     * @param e 异常
     */
    @ResponseBody
    @ExceptionHandler(value = {NotPermissionException.class, NotRoleException.class})
    public void forbidden(HttpServletRequest request, HttpServletResponse response, SaTokenException e) {
        String errorMsg = e.getMessage();
        log.error("没有权限！！{}", errorMsg);
        MsgUtil.httpError(response, request, e, HttpStatus.FORBIDDEN, BaseConstants.FORBIDDEN_CODE);
    }
}

==> applet-sa-boot-starter-3.2.3-sources.jar: cn/sinozg/applet/sa/handler/SaGlobalExceptionHandler.java <==
/*
 * Copyright (C) 2020-2024, Xie YuBin
 * The GNU Free Documentation License covers this file. The original version
 * of this license can be found at http://www.gnu.org/licenses/gfdl.html.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Free Documentation License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Free Documentation License for more details.
 *
 * You should have received a copy of the GNU Free Documentation License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package cn.sinozg.applet.sa.handler;

import cn.dev33.satoken.exception.NotLoginException;
import cn.dev33.satoken.exception.NotPermissionException;
import cn.dev33.satoken.exception.NotRoleException;
import cn.dev33.satoken.exception.SaTokenException;
import cn.sinozg.applet.common.constant.BaseConstants;
import cn.sinozg.applet.common.core.model.ErrorMsgInfo;
import cn.sinozg.applet.common.utils.MsgUtil;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.core.Ordered;
import org.springframework.core.annotation.Order;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestControllerAdvice;

import jakarta.servlet.http.HttpServletRequest;
import jakarta.servlet.http.HttpServletResponse;

/**
 * sa 异常全局拦截器
 * @author xieyubin
 * @Description
 * @Copyright Copyright (c) 2024
 * @since 2024-01-05 17:34
 */
@RestControllerAdvice
@Order(Ordered.HIGHEST_PRECEDENCE)
public class SaGlobalExceptionHandler {

    private static final Logger log = LoggerFactory.getLogger(SaGlobalExceptionHandler.class);
    /**
     * 鉴权异常处理
     * @param request HttpServletRequest
     * @param e 异常
     */
    @ResponseBody
    @ExceptionHandler(NotLoginException.class)
    public void nonLoginException(HttpServletRequest request, HttpServletResponse response, NotLoginException e) {
        log.error("未授权！！{}", request.getHeader(HttpHeaders.USER_AGENT));
        String errorMsg = e.getMessage();
        if (StringUtils.isNotEmpty(errorMsg)) {
            errorMsg = StringUtils.substringBefore(errorMsg, "：");
        }
        ErrorMsgInfo.Builder builder = new ErrorMsgInfo.Builder(BaseConstants.DEFAULT_CODE, e, request, response, errorMsg)
                .closeCause();
        MsgUtil.httpError(HttpStatus.UNAUTHORIZED, builder);
    }

    /**
     * 权限相关异常处理
     * @param request HttpServletRequest
     * @param response HttpServletResponse
     * @param e 异常
     */
    @ResponseBody
    @ExceptionHandler(value = {NotPermissionException.class, NotRoleException.class})
    public void forbidden(HttpServletRequest request, HttpServletResponse response, SaTokenException e) {
        String errorMsg = e.getMessage();
        log.error("没有权限！！{}", errorMsg);
        MsgUtil.httpError(HttpStatus.FORBIDDEN, new ErrorMsgInfo.Builder(BaseConstants.FORBIDDEN_CODE, e, request, response));
    }
}
